Learn R Programming

aqr (version 0.4)

aqLoadOHLC: Loads OHLC from an AQ Master Server

Description

Loads OHLC from an AQ Master Server

Usage

aqLoadOHLC(seriesId, freq, startDate, endDate, con = aqInit(), useCache = FALSE, cacheDir = getwd())

Arguments

seriesId
a series ID
freq
frequency in enumeration form, f.e. HOURS_1, MINUTES_1
startDate
a Date8
endDate
a Date8
con
a fully initialized connection definition
useCache
a boolean that says whether you want use and cache data
cacheDir
a directory name that will be used for caching if enabled

Value

a XTS object