Learn R Programming

aqr (version 0.2)

aqLoadOHLC: Loads a OHLCV data set from AQMS

Description

This function loads a Open/High/Low/Close/Volume data set from the AQ Master Server. If the master server does not contain data for a specified series Id, it will return an empty xts object.

Usage

aqLoadOHLC(seriesId, freq, startDate, endDate, con)

Arguments

See Also

aqInit.

Examples

Run this code
# creates a default configuration
        con = aqInit()
        # load data 
        EURUSD = aqLoadOHLC("CNX.MDI.EUR/USD", "HOURS_1",  20120601, 20120901, con)

Run the code above in your browser using DataLab