generatePnlCurve: method to generate a pnl curve from a running position.
bids, asks and running position must have the same length.
Can compute the pnl from one price to the other, but only for one asset!
Does not take time into account - if you need signal delays, lag
all input data on your own.
Description
method to generate a pnl curve from a running position.
bids, asks and running position must have the same length.
Can compute the pnl from one price to the other, but only
for one asset! Does not take time into account - if you
need signal delays, lag all input data on your own.